const Audit = require('lighthouse').Audit;

const MAX_PERMISSIBLE_DELAY = 2000;

class DataLoadTimeAudit extends Audit {
	static get meta() {
	  return {
	    id: "dataloadtime-audit",
	    title: "data load time metrics",
	    failureTitle: 'Too slow to load data from server',
	    description: 'Time to load data from server',
	    requiredArtifacts: ['DataLoadTimeGatherer']
	  };
	}
	
	static audit(artifacts) {
	  const dataLoadTime = artifacts.DataLoadTimeGatherer.dataLoadTime;
		
	  return {
	    rawValue: dataLoadTime,
	    score: Number(dataLoadTime <= MAX_PERMISSIBLE_DELAY),
	  };
	}
}

module.exports = DataLoadTimeAudit;